ListenerManager class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addErrorListener(ValueChanged<PurchaseError?> callback) → void
addProStatusChangedListener(ValueChanged<Purchase> callback) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyErrorListeners({PurchaseError? purchaseError}) → void
notifyProStatusChangedListeners(Purchase purchasedItem) → void
removeErrorListener(ValueChanged<PurchaseError?> callback) → void
removeProStatusChangedListener(ValueChanged<Purchase> callback) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ListenerManager
final